==> milligram-stylus-0.0.1.tgz: package/readme.md <==
# [Milligram](http://milligram.github.io)

| A minimalist CSS framework.

[![Build Status](https://travis-ci.org/milligram/milligram.svg?branch=master)](https://travis-ci.org/milligram/milligram)
[![GitHub version](https://badge.fury.io/gh/milligram%2Fmilligram.svg)](https://badge.fury.io/gh/milligram%2Fmilligram)
[![Bower version](https://badge.fury.io/bo/milligram.svg)](https://badge.fury.io/bo/milligram)
[![npm version](https://badge.fury.io/js/milligram.svg)](http://badge.fury.io/js/milligram)
[![Dependencies Status](https://david-dm.org/milligram/milligram.svg)](https://travis-ci.org/milligram/milligram)


## Why it's awesome?

Milligram provides a minimal setup of styles for a fast and clean starting point. Just it! **Only 2kb gzipped!** It's not about a UI framework. Specially designed for better performance and higher productivity with fewer properties to reset resulting in cleaner code. Hope you enjoy!


## Download

**Install with Bower**

```sh
$ bower install milligram
```

**Install with npm**

```sh
$ npm install milligram
```


## Table of Contents

- [Getting Started](http://milligram.github.io/#getting-started)
- [Typography](http://milligram.github.io/#typography)
- [Blockquotes](http://milligram.github.io/#blockquotes)
- [Buttons](http://milligram.github.io/#buttons)
- [Lists](http://milligram.github.io/#lists)
- [Forms](http://milligram.github.io/#forms)
- [Tables](http://milligram.github.io/#tables)
- [Grids](http://milligram.github.io/#grids)
- [Codes](http://milligram.github.io/#codes)
- [Utilities](http://milligram.github.io/#utilities)
- [Tips](http://milligram.github.io/#tips)
- [Browser Support](http://milligram.github.io/#browser-support)
- [Examples](http://milligram.github.io/#examples)


## Contributing

Help improve these docs. Open an [issue](https://github.com/milligram/milligram/issues/new) or submit a pull request.

- Navigate to the main page of the repository
- [Fork it!](https://github.com/milligram/milligram#fork-destination-box)
- Create your feature branch: git checkout -b my-new-feature
- Commit your changes: git commit -m 'Add some feature'
- Push to the branch: git push origin my-new-feature
- Submit a pull request =D


## License

[MIT License](http://cjpatoilo.mit-license.org/) @ CJ Patoilo

==> milligram-stylus-1.0.0.tgz: package/readme.md <==
# [Milligram](http://milligram.github.io)

| A minimalist CSS framework.

[![Build Status](https://travis-ci.org/milligram/milligram.svg?branch=master)](https://travis-ci.org/milligram/milligram)
[![GitHub version](https://badge.fury.io/gh/milligram%2Fmilligram.svg)](https://badge.fury.io/gh/milligram%2Fmilligram)
[![Bower version](https://badge.fury.io/bo/milligram.svg)](https://badge.fury.io/bo/milligram)
[![npm version](https://badge.fury.io/js/milligram.svg)](http://badge.fury.io/js/milligram)
[![Dependencies Status](https://david-dm.org/milligram/milligram.svg)](https://travis-ci.org/milligram/milligram)


## Why it's awesome?

Milligram provides a minimal setup of styles for a fast and clean starting point. Just it! **Only 2kb gzipped!** It's not about a UI framework. Specially designed for better performance and higher productivity with fewer properties to reset resulting in cleaner code. Hope you enjoy!


## Download

**Install with Bower**

```sh
$ bower install milligram-stylus
```

**Install with npm**

```sh
$ npm install milligram-stylus
```


## Table of Contents

- [Getting Started](http://milligram.github.io/#getting-started)
- [Typography](http://milligram.github.io/#typography)
- [Blockquotes](http://milligram.github.io/#blockquotes)
- [Buttons](http://milligram.github.io/#buttons)
- [Lists](http://milligram.github.io/#lists)
- [Forms](http://milligram.github.io/#forms)
- [Tables](http://milligram.github.io/#tables)
- [Grids](http://milligram.github.io/#grids)
- [Codes](http://milligram.github.io/#codes)
- [Utilities](http://milligram.github.io/#utilities)
- [Tips](http://milligram.github.io/#tips)
- [Browser Support](http://milligram.github.io/#browser-support)
- [Examples](http://milligram.github.io/#examples)


## Contributing

Help improve these docs. Open an [issue](https://github.com/milligram/milligram/issues/new) or submit a pull request.

- Navigate to the main page of the repository
- [Fork it!](https://github.com/milligram/milligram#fork-destination-box)
- Create your feature branch: git checkout -b my-new-feature
- Commit your changes: git commit -m 'Add some feature'
- Push to the branch: git push origin my-new-feature
- Submit a pull request =D


## License

[MIT License](http://cjpatoilo.mit-license.org/) @ CJ Patoilo
